# youtube_search

Python function for searching for youtube videos to avoid using their heavily rate-limited API

This basically scrapes the search results from the website, and will have more and more customization as I get around to adding it.